/*****************************************************************************
 *
 * Copyright:  Licensed Materials - Property of IBM
 *
 *             5622-078 (C) Copyright IBM Corp. 1992, 1996          @CM2CPYR
 *             5622-321 (C) Copyright IBM Corp. 1992, 1996          @CM2CPYR
 *             All rights reserved.
 *
 *             U.S. Government Users Restricted Rights -
 *             Use, duplication or disclosure restricted by
 *             GSA ADP Schedule Contract with IBM Corp.
 *
 ***************************************************************************
 *
 * Include File Name:           tn32intr.h
 *
 * Include Title:               TN3270E Server interface structures
 *
 * Function:                    Provides a common area for defining
 *                              TN3270E Server interface structures.
 *
 *==========================================================================*/
#ifndef tn32intrh
#define tn32intrh

#define MAX_LUNAME 8

/* Definition for Return code from API CALL */

#define TN3270_API_OK 0
#define TN3270_API_ERROR 255
#define TN3270_API_UNAVAILABLE 3


#ifndef ulong
#define ulong unsigned long
#endif

typedef struct lustatus_struct {

   int  status;
/* This is the status value returned on a display  */
/* It is the return code for a stop */

   char ip_addr[16];
/* this is the peer ip address returned on a display */
/* it is not used for stop */
/* it is formatted in dotted decimal notation and null_terminated */

   int lutype;
/* This is the lu type.  Either 1, 2 , or 3, returned on a display */
/* It is not used for stop */

   unsigned long idle_time;
/* this is the number of minutes that this session has been idle */

   char luname[MAX_LUNAME+1];
/* This is the LU Name being displayed or stopped */
/* If it is blank for display, then status for all LUS is returned */
/* If it is blank for stop, an error is returned */


   char pri_luname[MAX_LUNAME+MAX_LUNAME+2]; /* for netid.luname */
/* this is the application lu name returned on a display */
/* It is not used for stop */

   char sec_luname[MAX_LUNAME+MAX_LUNAME+2]; /* for netid.luname */
/* this is the depended lu name returned on a display */
/* It is not used for stop */

   char associated_lu[MAX_LUNAME+1];
/* this is the name of the lu that is associated with this one */

   int pool;
/* this is the lu pool that this lu is in. */
/* it is one of: */
#define POOL_TERMINAL_SPECIFIC 1
#define POOL_TERMINAL_GENERIC 2
#define POOL_PRINTER_SPECIFIC 3
#define POOL_PRINTER_GENERIC 4

   int associated_printer;
/* this is a logical value that tell if this lu is an associated printer */
/* or not.  It is either 0 or non-zero */

 } lustatus;

typedef lustatus alustatus[];

/*************************************************************************/
/* Values for status */
#define TN3270_LU_INACTIVE 0
#define TN3270_SSCP_SESSION 1
#define TN3270_LU_LU_SESSION 2
#define TN3270_STATUS_UNKNOWN 3
#define TN3270_STOP_SUCCESSFUL 4
#define TN3270_QUERY_UNSUCCESSFUL 5
#define TN3270_STATUS_PENDING 6
#define TN3270_LU_UNDEFINED 255
/*************************************************************************/

/*************************************************************************/
/* When loading the DLL, this is the ENUM value */
#define TN32_REQ_ENUM 1;

/*************************************************************************/




/***************************************************************************
 *             Data structures for TN3270-CM/2 Interface
 ****************************************************************************/
  /*
   * NOTE: in the structure below, both len and maxlen are the length of the
   *       entire structure, including the length fields.
   */
                                       /*                                   */
struct TN32DISP_CD                     /*                                   */
{                                      /* display TN3270 connection status  */

   unsigned long maxlen;               /* max length of buffer available    */
   /* on request it contains the maximum size of the request buffer */
   /* on response, it contains the total amount of data available   */
   /* Note that this value can be greater on response than on request */
   /* In this case, the requester should allocate a larger buffer and */
   /* re-issue the request */


   unsigned long len;                  /* length of buffer being used       */
   /* on request, it is ignored */
   /* on response, it contains the size of the returned data */

   lustatus  status_list[1]; /* first lustatus structure */
    /* this array contains the status of the lus */
    /* if the lu name is filled in on request, only the status */
    /* for that lu is returned */

    /*
     * NOTE:  The maxlen field in this structure will determine how many lustatus
     *        structures are appended to this one.
     */


};                                     /* when buf is freed, set len to 0   */
                                       /*                                   */
struct TN32STOP_CD                     /* stop TN3270 connection            */
{                                      /*                                   */
   lustatus status_stop;               /* pointer to buffer containing data */
};                                     /*                                   */

struct TN32DFLTS_CD                    /*                                   */
{                                      /*                                   */
   unsigned short port;                /* port number                       */
   short keepalive_type;               /* type of keepalive being used      */
  /*
   * Constants for keepalive value
   */
#define KEEPALIVE_NONE 0
#define KEEPALIVE_NOP  1
#define KEEPALIVE_TM   2
   unsigned long keepalive_frequency;  /* amount of idle time before a      */
                                       /*    keepalive request is sent      */
                                       /*    (in seconds)                   */
   unsigned long keepalive_timer;      /* amount of time to wait for a      */
                                       /*    timing mark keepalive response */
                                       /*    (in seconds)                   */
   unsigned long automatic_logoff;     /* amount of time to wait before     */
                                       /*    closing an idle connection     */
                                       /*    (in minutes)                   */
};                                     /*                                   */

#endif /* tn32intrh */
